#!/usr/bin/env bash

source .buildkite/scripts/common/util.sh

echo '--- Setting up bazel'

echo "[bazel] writing .bazelrc"
cat <<EOF > $KIBANA_DIR/.bazelrc
  # Generated by .buildkite/scripts/common/setup_bazel.sh

  import %workspace%/.bazelrc.common

  build --build_metadata=ROLE=CI
EOF

BAZEL_CACHE_MODE=${BAZEL_CACHE_MODE:-gcs}

if [[ "$BAZEL_CACHE_MODE" == "gcs" ]]; then
  echo "[bazel] enabling caching with GCS buckets"

  BAZEL_REGION="${BUILDKITE_AGENT_GCP_REGION:-us-central1}"

  if ! [[ "$BAZEL_REGION" =~ ^(us-central1|northamerica-northeast2|europe-west2|southamerica-east1|asia-south2)$ ]]; then
    echo "unsupported bazel cache region $BAZEL_REGION"
    exit 1
  fi

  BAZEL_BUCKET="kibana-ci-bazel_$BAZEL_REGION"

  echo "[bazel] using GCS bucket: $BAZEL_BUCKET"

  cat <<EOF >> $KIBANA_DIR/.bazelrc
  build --remote_cache=https://storage.googleapis.com/$BAZEL_BUCKET
  build --google_credentials=$BAZEL_REMOTE_CACHE_CREDENTIALS_FILE
EOF
fi

if [[ "$BAZEL_CACHE_MODE" == "populate-local-gcs" ]]; then
  echo "[bazel] enabling caching with GCS buckets for local dev"

  cat <<EOF >> $KIBANA_DIR/.bazelrc
  build --remote_cache=https://storage.googleapis.com/kibana-local-bazel-remote-cache
  build --google_credentials=$BAZEL_LOCAL_DEV_CACHE_CREDENTIALS_FILE
EOF
fi

if [[ "$BAZEL_CACHE_MODE" != @(gcs|populate-local-gcs|none|) ]]; then
  echo "invalid value for BAZEL_CACHE_MODE received ($BAZEL_CACHE_MODE), expected one of [gcs,populate-local-gcs|none]"
  exit 1
fi
